@@ -18,7 +18,7 @@ package StorageDisplay::Collect;
 # ABSTRACT: modules required to collect data.
 # No dependencies (but perl itself and its basic modules)
 
-our $VERSION = '1.2.3'; # VERSION
+our $VERSION = '1.2.4'; # VERSION
 
 
 sub collectors {
@@ -302,7 +302,7 @@ sub decode_json {
     $json_parser->decode(@_);
 }
 
-sub use_pp_parser {
+sub pp_parser_has_boolean_values {
     return $has_boolean_values;
 }
 
@@ -1884,7 +1884,7 @@ StorageDisplay::Collect - modules required to collect data.
 
 =head1 VERSION
 
-version 1.2.3
+version 1.2.4
 
 Main class, allows one to register collectors and run them
 (through the collect method)
